	SUBROUTINE JB_OPEN  ( filnam, ifn, iret )
C************************************************************************
C* JB_OPEN								*
C*									* 
C* This subroutine opens a Jack Woollen BUFR data file.			*
C*									*
C* JB_OPEN  ( FILNAM, IFN, IRET )					*
C*									*
C* Input parameters:							*
C*	FILNAM		CHAR*		Name of BUFR data file		*
C*	IFN		INTEGER		File unit number		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	 0 = normal return 		*
C*					-1 = cannot open file		*
C*					-2 = file name is blank		*
C**									*
C* Log:									*
C* K. Brill/EMC		10/96						*
C* K. Brill/EMC		12/96	Remove current file feature		*
C************************************************************************
	CHARACTER*(*)	filnam
C*-----------------------------------------------------------------------
	iret = 0
C*
	IF ( filnam .eq. ' ' ) THEN
	    iret = -2
	    RETURN
	END IF
C*
	OPEN ( UNIT = ifn, FILE = filnam, STATUS = 'OLD',
     +	       FORM = 'UNFORMATTED', IOSTAT = iostat )
	IF ( iostat .ne. 0 ) THEN
	    WRITE (6,*) filnam, ' must be blocked for unformatted ',
     +			'I/O.'
	    iret = -1
	    RETURN
	END IF
	CALL OPENBF ( ifn, 'IN', ifn )
C*
	RETURN
	END
